@@ -52,11 +52,8 @@ def print_update(durations: Durations, mode: str, show_options: bool = False, sh
         print_ops = '.. or chose an optional command (H for help)'
 
     print(
-        f"""
-Work length:        {Fore.RED}{durations.work.mins} minutes{Style.RESET_ALL}
-Rest length:        {Fore.GREEN}{durations.rest.mins} minutes{Style.RESET_ALL}
-Total work time:    {Fore.YELLOW}{int(durations.total_work_mins)} minutes{Style.RESET_ALL}
-Total rest time:    {Fore.YELLOW}{int(durations.total_rest_mins)} minutes{Style.RESET_ALL}
+        f"""Total {Fore.RED}work{Style.RESET_ALL} today:           {Fore.YELLOW}{int(durations.total_work_mins)} minutes{Style.RESET_ALL}
+Total {Fore.GREEN}rest{Style.RESET_ALL} today:           {Fore.YELLOW}{int(durations.total_rest_mins)} minutes{Style.RESET_ALL}
 
 Upcoming timer:     {upcoming_timer_color}{mode.upper()}{Style.RESET_ALL}
 
